# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLevelSetsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkShapePriorMAPCostFunctionBasePython
else:
    import _itkShapePriorMAPCostFunctionBasePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkRGBPixelPython
import itk.ITKCostFunctionsPython
import itk.itkArray2DPython
import itk.itkArrayPython
import itk.vnl_cost_functionPython
import itk.vnl_unary_functionPython
import itk.itkCostFunctionPython
import itk.itkOptimizerParametersPython
import itk.vnl_least_squares_functionPython
import itk.itkShapeSignedDistanceFunctionPython
import itk.itkSpatialFunctionPython
import itk.itkFunctionBasePython
import itk.itkContinuousIndexPython
import itk.ITKFastMarchingBasePython
import itk.itkFastMarchingStoppingCriterionBasePython
import itk.itkNodePairPython
import itk.itkLevelSetNodePython
import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
class itkShapePriorMAPCostFunctionBaseIF2F(itk.ITKCostFunctionsPython.itkSingleValuedCostFunction):
    r"""Proxy of C++ itkShapePriorMAPCostFunctionBaseIF2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetShapeFunction(self, _arg):
        r"""
        SetShapeFunction(self, _arg)

        Parameters
        ----------
        _arg: itkShapeSignedDistanceFunctionD2 *

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_SetShapeFunction(self, _arg)

    def GetModifiableShapeFunction(self):
        r"""GetModifiableShapeFunction(self) -> itkShapeSignedDistanceFunctionD2"""
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_GetModifiableShapeFunction(self)

    def GetShapeFunction(self, *args):
        r"""
        GetShapeFunction(self) -> itkShapeSignedDistanceFunctionD2
        GetShapeFunction(self) -> itkShapeSignedDistanceFunctionD2
        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_GetShapeFunction(self, *args)

    def SetActiveRegion(self, _arg):
        r"""
        SetActiveRegion(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUILSNF2 const *

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_SetActiveRegion(self, _arg)

    def GetActiveRegion(self):
        r"""GetActiveRegion(self) -> itkVectorContainerUILSNF2"""
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_GetActiveRegion(self)

    def SetFeatureImage(self, _arg):
        r"""
        SetFeatureImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_SetFeatureImage(self, _arg)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF2"""
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_GetFeatureImage(self)

    def ComputeLogInsideTerm(self, arg0):
        r"""
        ComputeLogInsideTerm(self, arg0) -> double

        Parameters
        ----------
        arg0: itkOptimizerParametersD const &

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_ComputeLogInsideTerm(self, arg0)

    def ComputeLogGradientTerm(self, arg0):
        r"""
        ComputeLogGradientTerm(self, arg0) -> double

        Parameters
        ----------
        arg0: itkOptimizerParametersD const &

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_ComputeLogGradientTerm(self, arg0)

    def ComputeLogShapePriorTerm(self, arg0):
        r"""
        ComputeLogShapePriorTerm(self, arg0) -> double

        Parameters
        ----------
        arg0: itkOptimizerParametersD const &

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_ComputeLogShapePriorTerm(self, arg0)

    def ComputeLogPosePriorTerm(self, arg0):
        r"""
        ComputeLogPosePriorTerm(self, arg0) -> double

        Parameters
        ----------
        arg0: itkOptimizerParametersD const &

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_ComputeLogPosePriorTerm(self, arg0)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_Initialize(self)
    __swig_destroy__ = _itkShapePriorMAPCostFunctionBasePython.delete_itkShapePriorMAPCostFunctionBaseIF2F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShapePriorMAPCostFunctionBaseIF2F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_cast(obj)

# Register itkShapePriorMAPCostFunctionBaseIF2F in _itkShapePriorMAPCostFunctionBasePython:
_itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF2F_swigregister(itkShapePriorMAPCostFunctionBaseIF2F)
class itkShapePriorMAPCostFunctionBaseIF3F(itk.ITKCostFunctionsPython.itkSingleValuedCostFunction):
    r"""Proxy of C++ itkShapePriorMAPCostFunctionBaseIF3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetShapeFunction(self, _arg):
        r"""
        SetShapeFunction(self, _arg)

        Parameters
        ----------
        _arg: itkShapeSignedDistanceFunctionD3 *

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_SetShapeFunction(self, _arg)

    def GetModifiableShapeFunction(self):
        r"""GetModifiableShapeFunction(self) -> itkShapeSignedDistanceFunctionD3"""
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_GetModifiableShapeFunction(self)

    def GetShapeFunction(self, *args):
        r"""
        GetShapeFunction(self) -> itkShapeSignedDistanceFunctionD3
        GetShapeFunction(self) -> itkShapeSignedDistanceFunctionD3
        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_GetShapeFunction(self, *args)

    def SetActiveRegion(self, _arg):
        r"""
        SetActiveRegion(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUILSNF3 const *

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_SetActiveRegion(self, _arg)

    def GetActiveRegion(self):
        r"""GetActiveRegion(self) -> itkVectorContainerUILSNF3"""
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_GetActiveRegion(self)

    def SetFeatureImage(self, _arg):
        r"""
        SetFeatureImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_SetFeatureImage(self, _arg)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF3"""
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_GetFeatureImage(self)

    def ComputeLogInsideTerm(self, arg0):
        r"""
        ComputeLogInsideTerm(self, arg0) -> double

        Parameters
        ----------
        arg0: itkOptimizerParametersD const &

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_ComputeLogInsideTerm(self, arg0)

    def ComputeLogGradientTerm(self, arg0):
        r"""
        ComputeLogGradientTerm(self, arg0) -> double

        Parameters
        ----------
        arg0: itkOptimizerParametersD const &

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_ComputeLogGradientTerm(self, arg0)

    def ComputeLogShapePriorTerm(self, arg0):
        r"""
        ComputeLogShapePriorTerm(self, arg0) -> double

        Parameters
        ----------
        arg0: itkOptimizerParametersD const &

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_ComputeLogShapePriorTerm(self, arg0)

    def ComputeLogPosePriorTerm(self, arg0):
        r"""
        ComputeLogPosePriorTerm(self, arg0) -> double

        Parameters
        ----------
        arg0: itkOptimizerParametersD const &

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_ComputeLogPosePriorTerm(self, arg0)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_Initialize(self)
    __swig_destroy__ = _itkShapePriorMAPCostFunctionBasePython.delete_itkShapePriorMAPCostFunctionBaseIF3F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShapePriorMAPCostFunctionBaseIF3F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_cast(obj)

# Register itkShapePriorMAPCostFunctionBaseIF3F in _itkShapePriorMAPCostFunctionBasePython:
_itkShapePriorMAPCostFunctionBasePython.itkShapePriorMAPCostFunctionBaseIF3F_swigregister(itkShapePriorMAPCostFunctionBaseIF3F)

